@@ -70,9 +70,18 @@
  * other programs which may modify your maildrops.
  * Currently you can only use one type.
  */
-#define FCNTL 1
-/* #define LOCKF 1 */
-/* #define FLOCK 1 */
+#define DOT_LOCKING   1
+/* #define FCNTL_LOCKING 1 */
+/* #define LOCKF_LOCKING 1 */
+/* #define FLOCK_LOCKING 1 */
+
+/*
+ * If you have defined DOT_LOCKING, this will specify
+ * the directory where file locks are placed, else the
+ * directory of the file to be locked is used.  Don't
+ * define this unless you know you need it.
+ */
+/* #define LOCKDIR "/usr/spool/locks" */
 
 /*
  * Define this if your passwords are stored in some type of
@@ -94,8 +103,8 @@
 #define DUMB    1
 
 /*
- * Directs inc to note "From " lines as Return Path:
- * info.
+ * Directs inc/slocal to note "From " lines as Return Path:
+ * info.  This is needed if you are using sendmail.
  */
 #define RPATHS  1
 
