@@ -145,7 +145,7 @@ struct msgs {
  */
 #define	MS_DEFAULT	0	/* default (one msg per file) */
 #define	MS_UNKNOWN	1	/* type not known yet         */
-#define	MS_UUCP		2	/* Unix-style "from" lines    */
+#define	MS_MBOX		2	/* Unix-style "from" lines    */
 #define	MS_MMDF		3	/* string mmdlm2              */
 #define	MS_MSH		4	/* whacko msh                 */
 
