@@ -113,3 +113,12 @@ int vfgets (FILE *, char **);
 char *strerror (int);
 #endif
 
+
+/*
+ * some prototypes for address parsing system
+ * (others are in addrsbr.h)
+ */
+char *LocalName(void);
+char *SystemName(void);
+char *UucpChan(void);
+char *OfficialName(char *);
