@@ -18,7 +18,7 @@
 
 		c == '\001' && peekc (iob) == '\001'
 
-   but it worked, and to increase generality, UUCP style maildrops could
+   but it worked, and to increase generality, MBOX style maildrops could
    be parsed as well.  Unfortunately the speed issue finally caught up with
    us since this routine is at the very heart of MH.
 
@@ -437,23 +437,25 @@ m_unknown(FILE *iob)
     register char *cp;
     register char *delimstr;
 
+/*
+ * Figure out what the message delimitter string is for this
+ * maildrop.  (This used to be part of m_Eom but I didn't like
+ * the idea of an "if" statement that could only succeed on the
+ * first call to m_Eom getting executed on each call, i.e., at
+ * every newline in the message).
+ *
+ * If the first line of the maildrop is a Unix "from" line, we
+ * say the style is MBOX and eat the rest of the line.  Otherwise
+ * we say the style is MMDF and look for the delimiter string
+ * specified when nmh was built (or from the mts.conf file).
+ */
+
     msg_style = MS_UNKNOWN;
 
-    /* Figure out what the message delimitter string is for this
-     * maildrop.  (This used to be part of m_Eom but I didn't like
-     * the idea of an "if" statement that could only succeed on the
-     * first call to m_Eom getting executed on each call, i.e., at
-     * every newline in the message).
-     *
-     * If the first line of the maildrop is a Unix "from" line, we say the
-     * style is UUCP and eat the rest of the line.  Otherwise we say the style
-     * is MMDF & look for the delimiter string specified when MH was built
-     * (or from the mts.conf file).
-     */
     pos = ftell (iob);
     if (fread (text, sizeof *text, 5, iob) == 5
 	    && strncmp (text, "From ", 5) == 0) {
-	msg_style = MS_UUCP;
+	msg_style = MS_MBOX;
 	delimstr = "\nFrom ";
 #ifndef	RPATHS
 	while ((c = getc (iob)) != '\n' && c >= 0)
@@ -539,7 +541,7 @@ m_Eom (int c, FILE *iob)
     pos = ftell (iob);
     if ((i = fread (text, sizeof *text, edelimlen, iob)) != edelimlen
 	    || strncmp (text, (char *)edelim, edelimlen)) {
-	if (i == 0 && msg_style == MS_UUCP)
+	if (i == 0 && msg_style == MS_MBOX)
 	    /* the final newline in the (brain damaged) unix-format
 	     * maildrop is part of the delimitter - delete it.
 	     */
@@ -554,7 +556,7 @@ m_Eom (int c, FILE *iob)
 	return 0;
     }
 
-    if (msg_style == MS_UUCP) {
+    if (msg_style == MS_MBOX) {
 #ifndef RPATHS
 	while ((c = getc (iob)) != '\n')
 	    if (c < 0)
