@@ -5,18 +5,17 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
+
 
 int
 m_seqflag (struct msgs *mp, char *cp)
 {
-    int bits;
-    register int i;
+    int i;
 
-    bits = FFATTRSLOT;
     for (i = 0; mp->msgattrs[i]; i++)
-	if (strcmp (mp->msgattrs[i], cp) == 0)
-	    return (1 << (bits + i));
+	if (!strcmp (mp->msgattrs[i], cp))
+	    return (1 << (FFATTRSLOT + i));
 
     return 0;
 }
