@@ -49,7 +49,7 @@ struct toktab {
     int tval;
 };
 
-static struct toktab toktab[] = {
+static struct toktab toktabs[] = {
     { "default",  DEFAULT },
     { "login",    LOGIN },
     { "password", PASSWD },
