@@ -138,6 +138,7 @@ static long pos;
 static long start;
 static long stop;
 
+static int mbx_style = MMDF_FORMAT;
 static int pd = NOTOK;
 static FILE *pf = NULL;
 #endif /* POP */
@@ -231,9 +232,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -367,8 +368,8 @@ main (int argc, char **argv)
     }
 
 #ifdef MAILGROUP
-    return_gid = getegid();	/* Save effective gid, assuming we'll use it */
-    setgid(getgid());		/* Turn off extraordinary privileges */
+    return_gid = getegid();  /* Save effective gid, assuming we'll use it */
+    setgid(getgid());        /* Turn off extraordinary privileges         */
 #endif	/* MAILGROUP */
 
 #ifdef POP
@@ -379,13 +380,13 @@ main (int argc, char **argv)
 #endif /* POP */
     if (from) {
 	newmail = from;
-#ifdef	POP
+#ifdef POP
 	host = NULL;
-#endif	/* POP */
+#endif /* POP */
 	if (stat (newmail, &s1) == NOTOK || s1.st_size == 0)
 	    adios (NULL, "no mail to incorporate");
     }
-#ifdef	POP
+#ifdef POP
     else if (host) {
 	if (user == NULL)
 	    user = getusr ();
@@ -470,18 +471,18 @@ go_to_it: ;
 
 #ifdef MAILGROUP
 	setgid(return_gid);	/* Reset gid to lock mail file */
-#endif	/* MAILGROUP */
+#endif /* MAILGROUP */
 	if ((in = lkfopen (newmail, "r")) == NULL)
 	    adios (NULL, "unable to lock and fopen %s", newmail);
 #ifdef MAILGROUP
 	setgid(getgid());	/* Return us to normal privileges */
-#endif	/* MAILGROUP */
+#endif /* MAILGROUP */
 	fstat (fileno(in), &s1);
     }
 
 #ifdef MAILGROUP
 	setgid(getgid());	/* Return us to normal privileges */
-#endif	/* MAILGROUP */
+#endif /* MAILGROUP */
 
     if (audfile) {
 	if ((i = stat (audfile, &st)) == NOTOK)
@@ -536,7 +537,7 @@ go_to_it: ;
 		free (cp);
 	    }
 	    msgnum = map_count ();
-	    if ((pd = mbx_open (file, getuid (), getgid (), m_gmprot ()))
+	    if ((pd = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ()))
 		    == NOTOK)
 		adios (file, "unable to open");
 	    if ((pf = fdopen (pd, "w+")) == NULL)
@@ -565,8 +566,7 @@ go_to_it: ;
 		if (fflush (pf))
 		    adios (file, "write error on");
 		fseek (pf, start, 0);
-	    }
-	    else {
+	    } else {
 		cp = getcpy (m_name (msgnum));
 		if ((pf = fopen (cp, "w+")) == NULL)
 		    adios (cp, "unable to write");
@@ -636,8 +636,7 @@ go_to_it: ;
 		    adios (file, "write error on");
 		}
 		map_write (file, pd, 0, 0L, start, stop, pos, size, noisy);
-	    }
-	    else {
+	    } else {
 		if (ferror(pf) || fclose (pf)) {
 		    int e = errno;
 		    unlink (cp);
