@@ -73,6 +73,8 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
+static int mbx_style = MMDF_FORMAT;
+
 /*
  * FOLDER
  */
@@ -1358,7 +1360,7 @@ quit (void)
     if (!getanswer (cp))
 	goto release;
     strcpy (tmpfil, m_backup (mp->foldpath));
-    if ((md = mbx_open (tmpfil, st.st_uid, st.st_gid, mode)) == NOTOK) {
+    if ((md = mbx_open (tmpfil, mbx_style, st.st_uid, st.st_gid, mode)) == NOTOK) {
 	advise (tmpfil, "unable to open");
 	goto release;
     }
