@@ -1470,6 +1470,7 @@ static struct swit packswit[] = {
     { NULL, 0 }
 };
 
+static mbx_style = MMDF_FORMAT;
 
 void
 packcmd (char **args)
@@ -1534,7 +1535,7 @@ packcmd (char **args)
 	    goto done_pack;
     m_setseq (mp);
 
-    if ((md = mbx_open (file, getuid (), getgid (), m_gmprot ())) == NOTOK) {
+    if ((md = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ())) == NOTOK) {
 	advise (file, "unable to open");
 	goto done_pack;
     }
