@@ -148,10 +148,10 @@ main (int argc, char **argv)
 #ifndef	TTYD
     if ((uf = fopen ("/etc/utmp", "r")) == NULL)
 	exit (RCV_MBX);
-    while (fread ((char *) &ut, sizeof ut, 1, uf) == 1)
+    while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
 	if (ut.ut_name[0] != 0
-		&& strncmp (user, ut.ut_name, sizeof ut.ut_name) == 0) {
-	    strncpy (tty, ut.ut_line, sizeof ut.ut_line);
+		&& strncmp (user, ut.ut_name, sizeof(ut.ut_name)) == 0) {
+	    strncpy (tty, ut.ut_line, sizeof(ut.ut_line));
 	    alert (tty, md);
 	}
     fclose (uf);
@@ -283,7 +283,7 @@ alert (char *tty, int md)
 
     lseek (md, (off_t) 0, SEEK_SET);
 
-    while ((i = read (md, buffer, sizeof buffer)) > 0)
+    while ((i = read (md, buffer, sizeof(buffer))) > 0)
 	if (write (td, buffer, i) != i)
 	    break;
 
@@ -303,7 +303,7 @@ alert (char *user, int md)
     SIGNAL (SIGPIPE, SIG_IGN);
 
     lseek (md, (off_t), SEEK_SET);
-    while ((i = read (md, buffer, sizeof buffer)) > 0)
+    while ((i = read (md, buffer, sizeof(buffer))) > 0)
 	if (write (td, buffer, i) != i)
 	    break;
 
