@@ -133,7 +133,7 @@ replout (FILE *inb, char *msg, char *drft)
 	if (cptr)
 	    cptr->c_text = getcpy (fcc);
     }
-    if (cp = getenv("USER")) {
+    if ((cp = getenv("USER"))) {
 	FINDCOMP (cptr, "user");
 	if (cptr)
 	    cptr->c_text = getcpy(cp);
@@ -153,7 +153,7 @@ replout (FILE *inb, char *msg, char *drft)
 		 * buffer as the component temp buffer (buffer switching
 		 * saves an extra copy of the component text).
 		 */
-		if (cptr = wantcomp[CHASH(name)])
+		if ((cptr = wantcomp[CHASH(name)]))
 		    do {
 			if (uleq(name, cptr->c_name)) {
 			    char_read += msg_count;
@@ -180,7 +180,7 @@ replout (FILE *inb, char *msg, char *drft)
 			    }
 			    break;
 			}
-		    } while (cptr = cptr->c_next);
+		    } while ((cptr = cptr->c_next));
 
 		while (state == FLDPLUS)
 		    state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb);
