@@ -16,6 +16,13 @@
 # define _cnt _w                /* Wretch */
 #endif
 
+#ifdef SCO_5_STDIO
+# define _ptr  __ptr
+# define _cnt  __cnt
+# define _base __base
+# define _filbuf(fp)  ((fp)->__cnt = 0, __filbuf(fp))
+#endif
+
 #define MAXSCANL 256		/* longest possible scan line */
 #define SBUFSIZ 512		/* buffer size for content part of header
 				 * fields.  We want this to be large
@@ -77,8 +84,6 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 
     /* first-time only initialization */
     if (!scanl) {
-	int bigwid;
-
 	if (width == 0) {
 	    if ((width = sc_width ()) < WIDTH/2)
 		width = WIDTH/2;
@@ -102,7 +107,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	    cptr->c_text = folder;
 	FINDCOMP(cptr, "encrypted");
 	if (!cptr)
-	    if (cptr = (struct comp *) calloc (1, sizeof *cptr)) {
+	    if ((cptr = (struct comp *) calloc (1, sizeof(*cptr)))) {
 		cptr->c_name = "encrypted";
 		cptr->c_next = wantcomp[i = CHASH (cptr->c_name)];
 		wantcomp[i] = cptr;
@@ -154,12 +159,12 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	    scnmsg = "/dev/null";
 	if ((scnout = fopen (scnmsg, "w")) == NULL)
 	    adios (scnmsg, "unable to write");
-#ifdef	RPATHS
+#ifdef RPATHS
 	if ((cp = unixline ()) && *cp != '\n') {
 	    FPUTS ("Return-Path: ");
 	    FPUTS (cp);
 	}
-#endif	/* RPATHS */
+#endif /* RPATHS */
     }
 
     /* scan - main loop */
@@ -294,7 +299,7 @@ finished:
 			    calloc((unsigned) 1, sizeof(*datecomp->c_tws));
 		    if (datecomp->c_tws == NULL)
 			adios (NULL, "unable to allocate tws buffer");
-  		    *datecomp->c_tws = *dlocaltime ((long *) &st.st_mtime);
+  		    *datecomp->c_tws = *dlocaltime ((time_t *) &st.st_mtime);
 		    datecomp->c_flags = -1;
 		} else {
 		    datecomp->c_flags = 0;
@@ -349,7 +354,7 @@ mh_fputs(char *s, FILE *stream)
 {
     char c;
 
-    while (c = *s++) 
+    while ((c = *s++)) 
 	if (putc (c,stream) == EOF )
 	    return(EOF);
     return (0);
