@@ -387,9 +387,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	     * leading "re:", everything but letters & smash
 	     * letters to lower case. 
 	     */
-	    register char  *cp,
-			   *cp2,
-			    c;
+	    register char  *cp, *cp2, c;
 
 	    cp = subjcomp;
 	    cp2 = subjcomp;
