@@ -238,7 +238,7 @@ PEERinit (int vecp, char *vec[])
     char buf1[BUFSIZ], buf2[BUFSIZ];
     register WINDOW **w;
 
-    signal (SIGPIPE, PIPEser);
+    SIGNAL (SIGPIPE, PIPEser);
 
     if (pipe (pfd0) == NOTOK || pipe (pfd1) == NOTOK)
 	adios ("pipe", "unable to");
@@ -261,9 +261,9 @@ PEERinit (int vecp, char *vec[])
 	    vec[vecp++] = buf2;
 	    vec[vecp] = NULL;
 
-	    signal (SIGINT, SIG_DFL);
-	    signal (SIGQUIT, SIG_DFL);
-	    signal (SIGTERM, SIG_DFL);
+	    SIGNAL (SIGINT, SIG_DFL);
+	    SIGNAL (SIGQUIT, SIG_DFL);
+	    SIGNAL (SIGTERM, SIG_DFL);
 
 	    vec[0] = r1bindex (vmhproc, '/');
 	    execvp (vmhproc, vec);
@@ -393,17 +393,18 @@ pTTY (void)
     if (ChangeWindowDepth (dfd, twd, 0) == NOTOK)
 	adios ("failed", "ChangeWindowDepth");
 
-    hstat = signal (SIGHUP, SIG_IGN);
-    istat = signal (SIGINT, SIG_IGN);
-    qstat = signal (SIGQUIT, SIG_IGN);
-    tstat = signal (SIGTERM, SIG_IGN);
+    /* should block here instead of ignore */
+    hstat = SIGNAL (SIGHUP, SIG_IGN);
+    istat = SIGNAL (SIGINT, SIG_IGN);
+    qstat = SIGNAL (SIGQUIT, SIG_IGN);
+    tstat = SIGNAL (SIGTERM, SIG_IGN);
 
     rc2rc (RC_ACK, 0, NULL, rc);
 
-    signal (SIGHUP, hstat);
-    signal (SIGINT, istat);
-    signal (SIGQUIT, qstat);
-    signal (SIGTERM, tstat);
+    SIGNAL (SIGHUP, hstat);
+    SIGNAL (SIGINT, istat);
+    SIGNAL (SIGQUIT, qstat);
+    SIGNAL (SIGTERM, tstat);
 
     switch (rc->rc_type) {
 	case RC_EOF: 
@@ -501,7 +502,7 @@ pFIN (void)
 
     switch (setjmp (PEERctx)) {
 	case OK: 
-	    signal (SIGALRM, ALRMser);
+	    SIGNAL (SIGALRM, ALRMser);
 	    alarm (ALARM);
 
 	    status = pidwait (PEERpid, OK);
@@ -1203,9 +1204,9 @@ SIGinit (void)
 	adios ("failed", "ioctl TIOCGLTC");
     sideground ();
 
-    signal (SIGHUP, SIGser);
-    signal (SIGINT, SIGser);
-    signal (SIGQUIT, SIGser);
+    SIGNAL (SIGHUP, SIGser);
+    SIGNAL (SIGINT, SIGser);
+    SIGNAL (SIGQUIT, SIGser);
 }
 
 
@@ -1224,14 +1225,14 @@ foreground (void)
 	if (pgrp == tpgrp)
 	    break;
 
-	tstat = signal (SIGTTIN, SIG_DFL);
+	tstat = SIGNAL (SIGTTIN, SIG_DFL);
 	kill (0, SIGTTIN);
-	signal (SIGTTIN, tstat);
+	SIGNAL (SIGTTIN, tstat);
     }
     
-    signal (SIGTTIN, SIG_IGN);
-    signal (SIGTTOU, SIG_IGN);
-    signal (SIGTSTP, SIG_IGN);
+    SIGNAL (SIGTTIN, SIG_IGN);
+    SIGNAL (SIGTTOU, SIG_IGN);
+    SIGNAL (SIGTSTP, SIG_IGN);
 #endif	TIOCGPGRP
 }
 
@@ -1240,9 +1241,9 @@ static void
 sideground (void)
 {
 #ifdef	TIOCGPGRP
-    signal (SIGTTIN, SIG_DFL);
-    signal (SIGTTOU, SIG_DFL);
-    signal (SIGTSTP, SIG_DFL);
+    SIGNAL (SIGTTIN, SIG_DFL);
+    SIGNAL (SIGTTOU, SIG_DFL);
+    SIGNAL (SIGTSTP, SIG_DFL);
 #endif	TIOCGPGRP
 }
 
@@ -1254,31 +1255,23 @@ ALRMser (int sig)
 }
 
 
-#ifdef	BSD42
-/* ARGSUSED */
-#endif	BSD42
-
 static int
 PIPEser (int sig)
 {
-#ifndef	BSD42
-    signal (sig, SIG_IGN);
-#endif	BSD42
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (sig, SIG_IGN);
+#endif
 
     adios (NULL, "lost peer");
 }
 
 
-#ifdef	BSD42
-/* ARGSUSED */
-#endif	BSD42
-
 static int
 SIGser (int sig)
 {
-#ifndef	BSD42
-    signal (sig, SIG_IGN);
-#endif	BSD42
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (sig, SIG_IGN);
+#endif
 
     done (1);
 }
