@@ -42,9 +42,9 @@ static char *tailor_value (char *);
  */
 static char *mtsconf = nmhetcdir(/mts.conf);
 
-static char *localname = "";
+static char *localname   = "";
 static char *localdomain = "";
-static char *systemname = "";
+static char *systemname  = "";
 
 #ifdef MF
 static char *UUCPchan = "";
@@ -67,10 +67,6 @@ char *umincproc = nmhetcdir(/uminc);
 char *umincproc = NULL;
 #endif
 
-int lockstyle = LOK_UNIX;
-static char *lkstyle = "0";
-char *lockldir = "";
-
 /*
  * MTS specific variables
  */
@@ -103,8 +99,8 @@ char *sendmail = SENDMAILPATH;
  * SMTP/POP stuff
  */
 char *clientname = NULL;
-char *servers = "localhost \01localnet";
-char *pophost = "";
+char *servers    = "localhost \01localnet";
+char *pophost    = "";
 
 /*
  * BBoards-specific variables
@@ -159,8 +155,6 @@ static struct bind binds[] = {
     { "mmdelim2", &mmdlm2 },
     { "mmailid", &mmailid },
     { "umincproc", &umincproc },
-    { "lockstyle", &lkstyle },
-    { "lockldir", &lockldir },
 
 #ifdef MHMTS
     { "mailqdir", &Mailqdir },
@@ -202,7 +196,7 @@ static struct bind binds[] = {
     { "maildelivery", &maildelivery },
     { "everyone", &everyone },
     { "noshell", &NoShell },
-    NULL
+    { NULL, NULL }
 };
 
 
@@ -250,15 +244,12 @@ mts_init (char *name)
     fclose (fp);
 
     MMailids = atoi (mmailid);
-    if ((lockstyle = atoi (lkstyle)) < LOK_UNIX || lockstyle > LOK_MMDF)
-	lockstyle = LOK_UNIX;
+    Everyone = atoi (everyone);
 
 #ifdef MHMTS
     Syscpy = atoi (syscpy);
     sscanf (tmpmode, "0%o", &Tmpmode);
 #endif /* MHMTS */
-
-    Everyone = atoi (everyone);
 }
 
 #define	QUOTE	'\\'
@@ -432,7 +423,7 @@ getusr (void)
 	     || *pw->pw_name == '\0') {
 #endif /* KPOP */
 	strcpy (username, "unknown");
-	sprintf (fullname, "The Unknown User-ID (%d)", getuid ());
+	sprintf (fullname, "The Unknown User-ID (%d)", (int) getuid ());
 	return username;
     }
 
